@@ -620,7 +620,7 @@ class DataClientV2(DataClient):
         return True
 
     @staticmethod
-    def delete_all_course_table(school_id):
+    def delete_all_course_table(school_id, semester_name):
         backbone = BackboneV2(school_id)
-        backbone.delete_all_table_manager()
+        backbone.delete_all_table_manager(semester_name)
         return True
