@@ -114,7 +114,7 @@ class Backbone(object):
         :param classroom_id: 教室id
         :return:
         """
-        print(">>> Delete course table")
+        print(">>> Delete classroom")
         self.nirvana_requester.delete_classroom(classroom_id)
 
     def delete_table_manager(self, manager_id):
@@ -141,6 +141,21 @@ class Backbone(object):
         data = res.get('results', [])
         return data
 
+    def get_rest_table_list(self, key=None, value=None):
+        """
+        获取旧的相同作息id
+        :param key:  判定相同作息的唯一标识字段
+        :param value: 唯一标识字段值
+        :return:
+        """
+        print(">>> Get rest table by {}".format(key))
+        if key and value is None:
+            value = getattr(self.rest_table, key)
+        param = {key: value} if key else {}
+        res = self.nirvana_requester.get_rest_table(param)
+        data = res.get('results', [])
+        return data
+
     def create_course_manager(self, is_active=True):
         """
         创建课程表
@@ -841,8 +856,8 @@ class BackboneV2(Backbone):
         self.relate_course_manager_field()
         self.relate_course_field()
         if create_manager:
-            self.delete_other_table_manager(semester_id=self.course_manager.semester_id,
-                                            remain=[self.course_manager.number])
+            # self.delete_other_table_manager(semester_id=self.course_manager.semester_id,
+            #                                 remain=[self.course_manager.number])
             self.create_course_manager(is_active)
         self.create_courses()
         self.wrap_course_map()
@@ -853,7 +868,14 @@ class BackboneV2(Backbone):
         semester = self.get_semester_list(params={"name": self.course_manager.semester_name})
         self.delete_other_table_manager(semester_id=semester[0]['uid'], remain=[self.course_manager.number])
 
-    def delete_all_table_manager(self):
-        managers = self.get_course_manager_list()
+    def delete_all_table_manager(self, semester_name):
+        semester = self.get_semester_list(params={"name": semester_name})
+        semester_id = semester[0]['uid'] if semester else None
+        if not semester_id:
+            return
+        managers = self.get_course_manager_list(key="semester", value=semester_id)
         for manager in managers:
             self.delete_table_manager(manager['uid'])
+        rest_tables = self.get_rest_table_list(key="semester", value=semester_id)
+        for rest_table in rest_tables:
+            self.delete_rest_table(rest_table['uid'])
