@@ -85,9 +85,10 @@ class CourseSync(BaseSync):
     def extract_course(self):
         double_number_map = self.get_double_map()
         today, last_day = self.get_date_range()
+        today, last_day = '2020-09-02', '2020-10-11'
         sql = "SELECT id, coursename, sectionid, classroomid, coursedate, weekday, userid, isteacher, deptname " \
               "FROM mid_attendschedule " \
-              "WHERE updateflag!=3 and coursedate > '{}' and coursedate <= '{}' ORDER BY weekday".format(today,
+              "WHERE updateflag!=3 and coursedate > '{}' and coursedate <= '{}' and deptname!='学生' ORDER BY weekday".format(today,
                                                                                                          last_day)
         self.cur.execute(sql)
         rows = self.cur.fetchall()
@@ -128,13 +129,6 @@ class CourseSync(BaseSync):
                     # course.class_name = class_name
                     course.required_student = False
                     self.course_map[course_number] = course
-                    if class_name and class_name in self.class_name_num:
-                        exist_class_sign = self.class_sign.get(class_name)
-                        if exist_class_sign and current_course_table != exist_class_sign:
-                            print("该班级{}已在{}课表出现，请检查数据".format(class_name, exist_class_sign))
-                            continue
-                        self.class_set[current_course_table].add(self.class_name_num[class_name])
-                        self.class_sign[class_name] = current_course_table
                     self.classroom_set[current_course_table].add(classroom_number)
                     self.classroom_sign[classroom_number] = current_course_table
                     self.course_container[current_course_table].append(course)
@@ -150,24 +144,33 @@ class CourseSync(BaseSync):
                     student_number = self.student_map.get(user_id)
                     if student_number:
                         course.add_student(student_number)
+                    if class_name and class_name in self.class_name_num:
+                        exist_class_sign = self.class_sign.get(class_name)
+                        if exist_class_sign and current_course_table != exist_class_sign:
+                            print("该班级{}已在{}课表出现，请检查数据".format(class_name, exist_class_sign))
+                            continue
+                        self.class_set[current_course_table].add(self.class_name_num[class_name])
+                        self.class_sign[class_name] = current_course_table
                 course.add_position(num, week, category, classroom_number)
 
     def sync(self):
+        self.create_course_manager()
         self.extract_course()
         if not self.course_map:
             logger.info("没有课程信息")
             return
-        begin_date, end_date = self.get_date_range(days=60)
+        # begin_date, end_date = self.get_date_range(days=60)
         course_table_name = "{}课表_{}".format(self.semester.name, str(uuid.uuid4())[:4])
-        course_table_number = get_md5_hash(course_table_name)[:20]
-        course_table = CourseTableManagerV2(name=course_table_name, number=course_table_number,
-                                            rest_name=self.rest_table.name, walking_mode=WalkingModeSet.WALKING,
-                                            begin_date=begin_date, end_date=end_date, semester_name=self.semester.name)
-        course_table.classrooms_num = list(self.classroom_map.values())
-        course_table.sections_num = list(self.class_set)
-        course_table.courses = list(self.course_map.values())
-        print(">>> CREATE_COURSE_TABLE")
-        logger.info(">>> CREATE_COURSE_TABLE")
-        self.client.create_course_table(self.school_id, course_table, is_active=True)
+        # course_table_number = get_md5_hash(course_table_name)[:20]
+        for course_table_name, course_table in self.course_table_managers.items():
+            # course_table = CourseTableManagerV2(name=course_table_name, number=course_table_number,
+            #                                     rest_name=self.rest_table.name, walking_mode=WalkingModeSet.WALKING,
+            #                                     begin_date=begin_date, end_date=end_date, semester_name=self.semester.name)
+            course_table.classrooms_num = list(self.classroom_set[course_table_name])
+            course_table.sections_num = list(self.class_set[course_table_name])
+            course_table.courses = list(self.course_container[course_table_name])
+            print(">>> CREATE_COURSE_TABLE")
+            logger.info(">>> CREATE_COURSE_TABLE")
+            self.client.create_course_table(self.school_id, course_table, is_active=True)
         self.client.active_semester(self.school_id, self.semester, delete_other=True)
         self.close_db()
