@@ -15,11 +15,15 @@ class SectionSync(BaseSync):
         self.name_num = {}
 
     def extract_section(self):
-        sql = "SELECT DPCODE1, DPNAME1 FROM BASE_CUSTDEPT ORDER BY DPCODE1"
+        sql = "SELECT DPCODE1, DPNAME1, DPNAME2 FROM BASE_CUSTDEPT ORDER BY DPCODE1"
         self.cur.execute(sql)
         rows = self.cur.fetchall()
         for row in rows:
-            code, name = row[0], row[1]
+            code, name1, name2 = row[0], row[1], row[2]
+            if name2 == "000":
+                name = name1
+            else:
+                name = "{}/{}".format(name1, name2)
             section = Class(name=name, number=code, grade="高中一年级", school=self.school_id)
             self.section_map[code] = section
             self.name_num[name] = code
