@@ -46,6 +46,6 @@ class StudentSync(BaseSync):
         if not self.student_map:
             logger.info("没有学生信息")
             return
-        code, data = self.client.create_student(self.student_list)
-        logger.info("Code: {}, Msg: {}".format(code, data))
+        # code, data = self.client.create_student(self.student_list)
+        # logger.info("Code: {}, Msg: {}".format(code, data))
         self.close_db()
