@@ -4,7 +4,7 @@ SCHOOL_NAME = os.environ.get("SCHOOL_NAME", "北京好专业考勤管理学校")
 NICE_SECRET_KEY = os.environ.get("NICE_SECRET_KEY", "ff48dec875cc56f330b28f14388b05e9")
 NICE_APP_KEY = os.environ.get("NICE_APP_KEY", "21b190d5785837695e8cade16410be3a")
 NICE_PROTOCOL = os.environ.get("NICE_PROTOCOL", "https")
-NICE_HOST = os.environ.get("NICE_HOST", "xgk.lanzhou.edu.cn:20952/schoolscheduleserv/integration")
+NICE_HOST = os.environ.get("NICE_HOST", "xgk.lanzhou.edu.cn/schoolscheduleserv/integration")
 # NICE_HOST = os.environ.get("NICE_HOST", "connect.nicezhuanye.com/schoolscheduleserv/integration")
 
 NIRVANA_PROTOCOL = os.environ.get("NIRVANA_PROTOCOL", "http")
